You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ibatis.apache.org by gb...@apache.org on 2006/11/19 17:07:48 UTC

svn commit: r476843 [1/3] - in /ibatis/trunk/cs/mapper: IBatisNet.DataMapper.Test/NUnit/SqlMapTests/ IBatisNet.DataMapper/ IBatisNet.DataMapper/Commands/ IBatisNet.DataMapper/Configuration/ IBatisNet.DataMapper/Configuration/Sql/ IBatisNet.DataMapper/C...

Author: gbayon
Date: Sun Nov 19 08:07:45 2006
New Revision: 476843

URL: http://svn.apache.org/viewvc?view=rev&rev=476843
Log:
Added ISqlMapSession 
+ add comments on Type Handler class

Added:
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapSession.cs
Modified:
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/NUnit/SqlMapTests/CacheTest.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ChangeLog.txt
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/IPreparedCommand.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Dynamic/DynamicSql.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/ISql.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/SimpleDynamic/SimpleDynamicSql.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/ProcedureSql.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/StaticSql.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.20005.csproj
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.csproj
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapper.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/ArgumentStrategy/SelectGenericListStrategy.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/CachingStatement.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/DeleteMappedStatement.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/IMappedStatement.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/InsertMappedStatement.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PaginatedList.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PostSelectStrategy/GenericListStrategy.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PropertStrategy/SelectGenericListStrategy.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/SelectMappedStatement.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/UpdateMappedStatement.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Scope/RequestScope.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/SessionStore/AbstractSessionStore.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/SessionStore/CallContextSessionStore.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/SessionStore/HybridWebThreadSessionStore.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/SessionStore/ISessionStore.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/SessionStore/WebSessionStore.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/SqlMapSession.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/SqlMapper.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/AnsiStringTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/BaseTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/BooleanTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/ByteArrayTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/ByteTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/CharTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/CustomTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/DBNullTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/DateTimeTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/DecimalTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/DoubleTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/EnumTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/GuidTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Int16TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Int32TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Int64TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableBooleanTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableByteTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableCharTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableDateTimeTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableDecimalTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableDoubleTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableGuidTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableInt16TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableInt32TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableInt64TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableSByteTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableSingleTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableTimeSpanTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableUInt16TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableUInt32TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/Nullables/NullableUInt64TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/ObjectTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/SingleTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/StringTypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/UInt16TypeHandler.cs
    ibatis/trunk/cs/mapper/IBatisNet.DataMapper/TypeHandlers/UnknownTypeHandler.cs

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/NUnit/SqlMapTests/CacheTest.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/NUnit/SqlMapTests/CacheTest.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/NUnit/SqlMapTests/CacheTest.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/NUnit/SqlMapTests/CacheTest.cs Sun Nov 19 08:07:45 2006
@@ -2,7 +2,6 @@
 using System;
 using System.Collections;
 using System.Threading;
-using IBatisNet.Common;
 using IBatisNet.Common.Utilities;
 using IBatisNet.DataMapper.Configuration.Cache;
 using IBatisNet.DataMapper.MappedStatements;
@@ -347,7 +346,7 @@
 				try 
 				{
 					IMappedStatement statement = _sqlMap.GetMappedStatement( _statementName );
-					IDalSession session = new SqlMapSession(sqlMap);
+                    ISqlMapSession session = new SqlMapSession(sqlMap);
 					session.OpenConnection();
 					IList list = statement.ExecuteQueryForList(session, null);
 

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ChangeLog.txt
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ChangeLog.txt?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ChangeLog.txt (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ChangeLog.txt Sun Nov 19 08:07:45 2006
@@ -207,20 +207,20 @@
 - Added Xml Comment
 - Fixed possible issue in ApplyParameterMap (https://sourceforge.net/forum/message.php?msg_id=2841897)
 - Added support for C# using syntax in DataAccess/DataMapper
-       * using ( IDalSession session = daoManager.OpenConnection() )
+       * using ( SqlMapSession session = daoManager.OpenConnection() )
 			{
 			   ...db operations...
 			}
-       * using ( IDalSession session = daoManager.BeginTransaction() )
+       * using ( SqlMapSession session = daoManager.BeginTransaction() )
 			{
 			   ...db operations...
 			   session.Complete(); // Commit
 			}
-	   * using ( IDalSession session = sqlMap.OpenConnection() )
+	   * using ( SqlMapSession session = sqlMap.OpenConnection() )
 			{
 			   ...db operations...
 			}
-       * using ( IDalSession session = sqlMap.BeginTransaction() )
+       * using ( SqlMapSession session = sqlMap.BeginTransaction() )
 			{
 			   ...db operations...
 			   session.Complete(); // Commit

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs Sun Nov 19 08:07:45 2006
@@ -1660,7 +1660,7 @@
 				else if (statement is Statement)
 				{
 					sql = new StaticSql(_configScope, statement);
-					IDalSession session = new SqlMapSession(_configScope.SqlMapper);
+					ISqlMapSession session = new SqlMapSession(_configScope.SqlMapper);
 
 					((StaticSql)sql).BuildPreparedStatement( session, newSql );
 				}					
@@ -1755,7 +1755,7 @@
 			generatedSQL = SqlGenerator.BuildQuery(statement);
 
 			ISql sql = new StaticSql(configScope, statement);
-			IDalSession session = new SqlMapSession(configScope.SqlMapper);
+			ISqlMapSession session = new SqlMapSession(configScope.SqlMapper);
 
 			((StaticSql)sql).BuildPreparedStatement( session, generatedSQL );
 			statement.Sql = sql;

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Dynamic/DynamicSql.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Dynamic/DynamicSql.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Dynamic/DynamicSql.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Dynamic/DynamicSql.cs Sun Nov 19 08:07:45 2006
@@ -29,9 +29,6 @@
 using System.Collections;
 using System.Data;
 using System.Text;
-using IBatisNet.Common;
-using IBatisNet.Common.Utilities.Objects;
-using IBatisNet.Common.Utilities.Objects.Members;
 using IBatisNet.DataMapper.Configuration.ParameterMapping;
 using IBatisNet.DataMapper.Configuration.Sql.Dynamic.Elements;
 using IBatisNet.DataMapper.Configuration.Sql.Dynamic.Handlers;
@@ -40,7 +37,6 @@
 using IBatisNet.DataMapper.DataExchange;
 using IBatisNet.DataMapper.MappedStatements;
 using IBatisNet.DataMapper.Scope;
-using IBatisNet.DataMapper.TypeHandlers;
 
 #endregion
 
@@ -108,7 +104,7 @@
 		/// <param name="mappedStatement">The <see cref="IMappedStatement"/>.</param>
 		/// <returns>A new <see cref="RequestScope"/>.</returns>
 		public RequestScope GetRequestScope(IMappedStatement mappedStatement, 
-			object parameterObject, IDalSession session)
+			object parameterObject, ISqlMapSession session)
 		{ 
 			RequestScope request = new RequestScope( _dataExchangeFactory, session, _statement);
 
@@ -303,7 +299,7 @@
 		/// <param name="request"></param>
 		/// <param name="sqlStatement"></param>
 		/// <returns></returns>
-		private PreparedStatement BuildPreparedStatement(IDalSession session, RequestScope request, string sqlStatement)
+		private PreparedStatement BuildPreparedStatement(ISqlMapSession session, RequestScope request, string sqlStatement)
 		{
 			PreparedStatementFactory factory = new PreparedStatementFactory( session, request, _statement, sqlStatement);
 			return factory.Prepare();

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/ISql.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/ISql.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/ISql.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/ISql.cs Sun Nov 19 08:07:45 2006
@@ -25,7 +25,6 @@
 #endregion
 
 using System.Data;
-using IBatisNet.Common;
 using IBatisNet.DataMapper.MappedStatements;
 using IBatisNet.DataMapper.Scope;
 
@@ -48,7 +47,7 @@
 		/// <param name="session">The current session</param>
 		/// <param name="mappedStatement">The <see cref="IMappedStatement"/>.</param>
 		/// <returns>A new <see cref="RequestScope"/>.</returns>
-		RequestScope GetRequestScope(IMappedStatement mappedStatement, object parameterObject, IDalSession session);
+		RequestScope GetRequestScope(IMappedStatement mappedStatement, object parameterObject, ISqlMapSession session);
 		#endregion
 
 	}

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/SimpleDynamic/SimpleDynamicSql.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/SimpleDynamic/SimpleDynamicSql.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/SimpleDynamic/SimpleDynamicSql.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/SimpleDynamic/SimpleDynamicSql.cs Sun Nov 19 08:07:45 2006
@@ -29,15 +29,12 @@
 using System.Collections;
 using System.Text;
 
-using IBatisNet.Common;
-using IBatisNet.Common.Utilities.Objects.Members;
 using IBatisNet.DataMapper.Configuration.Sql;
 using IBatisNet.DataMapper.Configuration.Statements;
 using IBatisNet.DataMapper.DataExchange;
 using IBatisNet.DataMapper.MappedStatements;
 using IBatisNet.DataMapper.Scope;
 using IBatisNet.DataMapper.Exceptions;
-using IBatisNet.DataMapper.TypeHandlers;
 using IBatisNet.Common.Utilities;
 using IBatisNet.Common.Utilities.Objects;
 #endregion
@@ -184,7 +181,7 @@
 		/// <param name="mappedStatement">The <see cref="IMappedStatement"/>.</param>
 		/// <returns>A new <see cref="RequestScope"/>.</returns>
 		public RequestScope GetRequestScope(IMappedStatement mappedStatement, 
-			object parameterObject, IDalSession session)
+			object parameterObject, ISqlMapSession session)
 		{
 			string sqlStatement = ProcessDynamicElements(parameterObject);
 			
@@ -202,7 +199,7 @@
 		/// <param name="session"></param>
 		/// <param name="request"></param>
 		/// <param name="sqlStatement"></param>
-		private PreparedStatement BuildPreparedStatement(IDalSession session, RequestScope request, string sqlStatement)
+		private PreparedStatement BuildPreparedStatement(ISqlMapSession session, RequestScope request, string sqlStatement)
 		{
 			PreparedStatementFactory factory = new PreparedStatementFactory( session, request, _statement, sqlStatement);
 			return factory.Prepare();

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/ProcedureSql.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/ProcedureSql.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/ProcedureSql.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/ProcedureSql.cs Sun Nov 19 08:07:45 2006
@@ -25,15 +25,10 @@
 
 #region Using
 using System;
-
-using IBatisNet.Common;
-using IBatisNet.Common.Utilities.Objects;
-using IBatisNet.Common.Utilities.Objects.Members;
 using IBatisNet.DataMapper.Configuration.Statements;
 using IBatisNet.DataMapper.DataExchange;
 using IBatisNet.DataMapper.MappedStatements;
 using IBatisNet.DataMapper.Scope;
-using IBatisNet.DataMapper.TypeHandlers;
 
 #endregion
 
@@ -80,7 +75,7 @@
 		/// <param name="mappedStatement">The <see cref="IMappedStatement"/>.</param>
 		/// <returns>A new <see cref="RequestScope"/>.</returns>
 		public RequestScope GetRequestScope(IMappedStatement mappedStatement, 
-			object parameterObject, IDalSession session)
+			object parameterObject, ISqlMapSession session)
 		{
 			RequestScope request = new RequestScope(_dataExchangeFactory, session, _statement);
 
@@ -96,7 +91,7 @@
 		/// <param name="session"></param>
 		/// <param name="commandText"></param>
 		/// <param name="request"></param>
-		public PreparedStatement BuildPreparedStatement(IDalSession session, RequestScope request, string commandText)
+		public PreparedStatement BuildPreparedStatement(ISqlMapSession session, RequestScope request, string commandText)
 		{
 			if ( _preparedStatement == null )
 			{

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/StaticSql.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/StaticSql.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/StaticSql.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Sql/Static/StaticSql.cs Sun Nov 19 08:07:45 2006
@@ -26,14 +26,10 @@
 
 #region Imports
 
-using IBatisNet.Common;
-using IBatisNet.Common.Utilities.Objects;
-using IBatisNet.Common.Utilities.Objects.Members;
 using IBatisNet.DataMapper.Configuration.Statements;
 using IBatisNet.DataMapper.DataExchange;
 using IBatisNet.DataMapper.MappedStatements;
 using IBatisNet.DataMapper.Scope;
-using IBatisNet.DataMapper.TypeHandlers;
 
 #endregion
 
@@ -77,7 +73,7 @@
 		/// <param name="mappedStatement">The <see cref="IMappedStatement"/>.</param>
 		/// <returns>A new <see cref="RequestScope"/>.</returns>
 		public RequestScope GetRequestScope(IMappedStatement mappedStatement,
-			object parameterObject, IDalSession session)
+			object parameterObject, ISqlMapSession session)
 		{
 			RequestScope request = new RequestScope(_dataExchangeFactory, session, _statement);
 
@@ -92,7 +88,7 @@
 		/// </summary>
 		/// <param name="session"></param>
 		/// <param name="sqlStatement"></param>
-		public void BuildPreparedStatement(IDalSession session, string sqlStatement)
+		public void BuildPreparedStatement(ISqlMapSession session, string sqlStatement)
 		{
 			RequestScope request = new RequestScope( _dataExchangeFactory, session, _statement);
 

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs Sun Nov 19 08:07:45 2006
@@ -32,7 +32,6 @@
 using System.Data;
 using System.Reflection;
 using System.Text;
-using IBatisNet.Common;
 using IBatisNet.Common.Logging;
 using IBatisNet.Common.Utilities;
 using IBatisNet.Common.Utilities.Objects;
@@ -56,7 +55,7 @@
 
 		private string _parameterPrefix = string.Empty;
 		private IStatement _statement = null;
-		private SqlMapSession _session = null;
+		private ISqlMapSession _session = null;
 		private string _commandText = string.Empty;
 		private RequestScope _request = null;
 		// (property, DbParameter)
@@ -73,9 +72,9 @@
 		/// <param name="statement"></param>
 		/// <param name="commandText"></param>
 		/// <param name="request"></param>
-		public PreparedStatementFactory(IDalSession session, RequestScope request, IStatement statement, string commandText)
+		public PreparedStatementFactory(ISqlMapSession session, RequestScope request, IStatement statement, string commandText)
 		{
-			_session = (SqlMapSession)session;
+			_session = session;
 			_request = request;
 			_statement = statement;
 			_commandText = commandText;
@@ -165,7 +164,7 @@
 		/// For store procedure, auto discover IDataParameters for stored procedures at run-time.
 		/// </summary>
 		/// <param name="session">The current session.</param>
-		private void DiscoverParameter(SqlMapSession session)
+		private void DiscoverParameter(ISqlMapSession session)
 		{
 			// pull the parameters for this stored procedure from the parameter cache 
 			// (or discover them & populate the cache)

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.20005.csproj
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.20005.csproj?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.20005.csproj (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.20005.csproj Sun Nov 19 08:07:45 2006
@@ -470,6 +470,7 @@
       <SubType>Code</SubType>
     </Compile>
     <Compile Include="ISqlMapper.cs" />
+    <Compile Include="ISqlMapSession.cs" />
     <Compile Include="MappedStatements\ArgumentStrategy\ArgumentStrategyFactory.cs" />
     <Compile Include="MappedStatements\ArgumentStrategy\DefaultStrategy.cs" />
     <Compile Include="MappedStatements\ArgumentStrategy\IArgumentStrategy.cs" />

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.csproj
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.csproj?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.csproj (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/IBatisNet.DataMapper.csproj Sun Nov 19 08:07:45 2006
@@ -138,6 +138,11 @@
                     BuildAction = "Compile"
                 />
                 <File
+                    RelPath = "ISqlMapSession.cs"
+                    SubType = "Code"
+                    BuildAction = "Compile"
+                />
+                <File
                     RelPath = "licence.txt"
                     BuildAction = "Content"
                 />

Added: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapSession.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapSession.cs?view=auto&rev=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapSession.cs (added)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapSession.cs Sun Nov 19 08:07:45 2006
@@ -0,0 +1,52 @@
+#region Apache Notice
+/*****************************************************************************
+ * $Revision: 474910 $
+ * $LastChangedDate: 2006-11-14 19:33:12 +0100 (mar., 14 nov. 2006) $
+ * $LastChangedBy: gbayon $
+ * 
+ * iBATIS.NET Data Mapper
+ * Copyright (C) 2006/2005 - The Apache Software Foundation
+ *  
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ * 
+ ********************************************************************************/
+#endregion
+
+using IBatisNet.Common;
+
+namespace IBatisNet.DataMapper
+{
+    /// <summary>
+    /// SqlMap Session contract
+    /// </summary>
+    public interface ISqlMapSession : IDalSession
+    {
+
+        /// <summary>
+        /// Gets the SQL mapper.
+        /// </summary>
+        /// <value>The SQL mapper.</value>
+        ISqlMapper SqlMapper { get; }
+
+        /// <summary>
+        /// Create the connection
+        /// </summary>
+        void CreateConnection();
+
+        /// <summary>
+        /// Create the connection
+        /// </summary>
+        void CreateConnection(string connectionString);
+    }
+}
\ No newline at end of file

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapper.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapper.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapper.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/ISqlMapper.cs Sun Nov 19 08:07:45 2006
@@ -23,6 +23,7 @@
  ********************************************************************************/
 #endregion
 
+#region using
 using System;
 using System.Collections;
 #if dotnet2
@@ -42,6 +43,7 @@
 using IBatisNet.DataMapper.MappedStatements;
 using IBatisNet.DataMapper.SessionStore;
 using IBatisNet.DataMapper.TypeHandlers;
+#endregion
 
 namespace IBatisNet.DataMapper
 {
@@ -77,13 +79,13 @@
         ///  Returns the DalSession instance 
         ///  currently being used by the SqlMap.
         /// </summary>
-        IDalSession LocalSession { get; }
+        ISqlMapSession LocalSession { get; }
 
         /// <summary>
-        /// Creates a new IDalSession that will be used to query the data source.
+        /// Creates a new SqlMapSession that will be used to query the data source.
         /// </summary>
         /// <returns>A new session</returns>
-        IDalSession CreateSqlMapSession();
+        ISqlMapSession CreateSqlMapSession();
         
         /// <summary>
         /// A flag that determines whether cache models were enabled 
@@ -176,21 +178,21 @@
         /// Begins the transaction.
         /// </summary>
         /// <returns></returns>
-        IDalSession BeginTransaction();
+        ISqlMapSession BeginTransaction();
 
         /// <summary>
         /// Begins the transaction.
         /// </summary>
         /// <param name="openConnection">if set to <c>true</c> [open connection].</param>
         /// <returns></returns>
-        IDalSession BeginTransaction(bool openConnection);
+        ISqlMapSession BeginTransaction(bool openConnection);
 
         /// <summary>
         /// Begins the transaction.
         /// </summary>
         /// <param name="connectionString">The connection string.</param>
         /// <returns></returns>
-        IDalSession BeginTransaction(string connectionString);
+        ISqlMapSession BeginTransaction(string connectionString);
 
         /// <summary>
         /// Begins the transaction.
@@ -198,7 +200,7 @@
         /// <param name="openNewConnection">if set to <c>true</c> [open new connection].</param>
         /// <param name="isolationLevel">The isolation level.</param>
         /// <returns></returns>
-        IDalSession BeginTransaction(bool openNewConnection, IsolationLevel isolationLevel);
+        ISqlMapSession BeginTransaction(bool openNewConnection, IsolationLevel isolationLevel);
 
         /// <summary>
         /// Begins the transaction.
@@ -207,14 +209,14 @@
         /// <param name="openNewConnection">if set to <c>true</c> [open new connection].</param>
         /// <param name="isolationLevel">The isolation level.</param>
         /// <returns></returns>
-        IDalSession BeginTransaction(string connectionString, bool openNewConnection, IsolationLevel isolationLevel);
+        ISqlMapSession BeginTransaction(string connectionString, bool openNewConnection, IsolationLevel isolationLevel);
 
         /// <summary>
         /// Begins the transaction.
         /// </summary>
         /// <param name="isolationLevel">The isolation level.</param>
         /// <returns></returns>
-        IDalSession BeginTransaction(IsolationLevel isolationLevel);
+        ISqlMapSession BeginTransaction(IsolationLevel isolationLevel);
 
         /// <summary>
         /// Begins the transaction.
@@ -222,7 +224,7 @@
         /// <param name="connectionString">The connection string.</param>
         /// <param name="isolationLevel">The isolation level.</param>
         /// <returns></returns>
-        IDalSession BeginTransaction(string connectionString, IsolationLevel isolationLevel);
+        ISqlMapSession BeginTransaction(string connectionString, IsolationLevel isolationLevel);
        
         /// <summary>
         /// Closes the connection.
@@ -295,14 +297,14 @@
         /// Opens the connection.
         /// </summary>
         /// <returns></returns>
-        IDalSession OpenConnection();
+        ISqlMapSession OpenConnection();
 
         /// <summary>
         /// Opens the connection.
         /// </summary>
         /// <param name="connectionString">The connection string.</param>
         /// <returns></returns>
-        IDalSession OpenConnection(string connectionString);
+        ISqlMapSession OpenConnection(string connectionString);
 
         /// <summary>
         /// Alias to QueryForMap, .NET spirit.

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/ArgumentStrategy/SelectGenericListStrategy.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/ArgumentStrategy/SelectGenericListStrategy.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/ArgumentStrategy/SelectGenericListStrategy.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/ArgumentStrategy/SelectGenericListStrategy.cs Sun Nov 19 08:07:45 2006
@@ -69,7 +69,7 @@
 
             Type mappedStatementType = selectStatement.GetType();
 
-            Type[] typeArguments = { typeof(IDalSession), typeof(object) };
+            Type[] typeArguments = { typeof(SqlMapSession), typeof(object) };
 
             MethodInfo[] mis = mappedStatementType.GetMethods(BindingFlags.InvokeMethod | BindingFlags.Public | BindingFlags.Instance);
             MethodInfo mi = null;

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/CachingStatement.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/CachingStatement.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/CachingStatement.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/CachingStatement.cs Sun Nov 19 08:07:45 2006
@@ -30,10 +30,8 @@
 using System.Collections.Generic;
 #endif
 using System.Data;
-using IBatisNet.Common;
 using IBatisNet.DataMapper.Commands;
 using IBatisNet.DataMapper.Configuration.Cache;
-using IBatisNet.DataMapper.Configuration.ResultMapping;
 using IBatisNet.DataMapper.Configuration.Statements;
 using IBatisNet.DataMapper.Scope;
 
@@ -109,7 +107,7 @@
 		/// <param name="valueProperty">The property of the result object to be used as the value (or null)</param>
 		/// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
 		///<exception cref="IBatisNet.DataMapper.Exceptions.DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-		public IDictionary ExecuteQueryForMap(IDalSession session, object parameterObject, string keyProperty, string valueProperty)
+		public IDictionary ExecuteQueryForMap(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty)
 		{
 			IDictionary map = new Hashtable();
 			RequestScope request = this.Statement.Sql.GetRequestScope(this, parameterObject, session);
@@ -151,7 +149,7 @@
         /// <param name="valueProperty">The property of the result object to be used as the value (or null)</param>
         /// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
         ///<exception cref="IBatisNet.DataMapper.Exceptions.DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-        public IDictionary<K, V> ExecuteQueryForDictionary<K, V>(IDalSession session, object parameterObject, string keyProperty, string valueProperty)
+        public IDictionary<K, V> ExecuteQueryForDictionary<K, V>(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty)
         {
             IDictionary<K, V> map = new Dictionary<K, V>();
             RequestScope request = this.Statement.Sql.GetRequestScope(this, parameterObject, session);
@@ -190,7 +188,7 @@
         /// <param name="rowDelegate"></param>
         /// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
         /// <exception cref="IBatisNet.DataMapper.Exceptions.DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-        public IDictionary<K, V> ExecuteQueryForDictionary<K, V>(IDalSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate<K, V> rowDelegate)
+        public IDictionary<K, V> ExecuteQueryForDictionary<K, V>(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate<K, V> rowDelegate)
         {
             return _mappedStatement.ExecuteQueryForDictionary<K, V>(session, parameterObject, keyProperty, valueProperty, rowDelegate);
         }
@@ -204,7 +202,7 @@
 		/// <param name="session">The session used to execute the statement.</param>
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <returns>The number of row effected.</returns>
-		public int ExecuteUpdate(IDalSession session, object parameterObject)
+		public int ExecuteUpdate(ISqlMapSession session, object parameterObject)
 		{
 			return _mappedStatement.ExecuteUpdate(session, parameterObject);
 		}
@@ -216,7 +214,7 @@
 		/// <param name="session">The session</param>
 		/// <param name="parameterObject">The parameter object used to fill the statement.</param>
 		/// <returns>Can return the insert generated key.</returns>
-		public object ExecuteInsert(IDalSession session, object parameterObject)
+		public object ExecuteInsert(ISqlMapSession session, object parameterObject)
 		{
 			return _mappedStatement.ExecuteInsert(session, parameterObject);
         }
@@ -229,7 +227,7 @@
 		/// <param name="session">The session used to execute the statement.</param>
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <param name="resultObject">A strongly typed collection of result objects.</param>
-		public void ExecuteQueryForList(IDalSession session, object parameterObject, IList resultObject)
+		public void ExecuteQueryForList(ISqlMapSession session, object parameterObject, IList resultObject)
 		{
 			_mappedStatement.ExecuteQueryForList(session, parameterObject, resultObject);
 		}
@@ -242,7 +240,7 @@
 		/// <param name="skipResults">The number of rows to skip over.</param>
 		/// <param name="maxResults">The maximum number of rows to return.</param>
 		/// <returns>A List of result objects.</returns>
-		public IList ExecuteQueryForList(IDalSession session, object parameterObject, int skipResults, int maxResults)
+		public IList ExecuteQueryForList(ISqlMapSession session, object parameterObject, int skipResults, int maxResults)
 		{
 			IList list = null;
 			RequestScope request = this.Statement.Sql.GetRequestScope(this, parameterObject, session);
@@ -270,7 +268,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>A List of result objects.</returns>
-        public IList ExecuteQueryForList(IDalSession session, object parameterObject)
+        public IList ExecuteQueryForList(ISqlMapSession session, object parameterObject)
         {
             return this.ExecuteQueryForList(session, parameterObject, MappedStatement.NO_SKIPPED_RESULTS, MappedStatement.NO_MAXIMUM_RESULTS);
         }
@@ -285,7 +283,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">A strongly typed collection of result objects.</param>
-        public void ExecuteQueryForList<T>(IDalSession session, object parameterObject, IList<T> resultObject)
+        public void ExecuteQueryForList<T>(ISqlMapSession session, object parameterObject, IList<T> resultObject)
         {
             _mappedStatement.ExecuteQueryForList(session, parameterObject, resultObject);
         }
@@ -298,7 +296,7 @@
         /// <param name="skipResults">The number of rows to skip over.</param>
         /// <param name="maxResults">The maximum number of rows to return.</param>
         /// <returns>A List of result objects.</returns>
-        public IList<T> ExecuteQueryForList<T>(IDalSession session, object parameterObject, int skipResults, int maxResults)
+        public IList<T> ExecuteQueryForList<T>(ISqlMapSession session, object parameterObject, int skipResults, int maxResults)
         {
             IList<T> list = null;
             RequestScope request = this.Statement.Sql.GetRequestScope(this, parameterObject, session);
@@ -326,7 +324,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>A List of result objects.</returns>
-        public IList<T> ExecuteQueryForList<T>(IDalSession session, object parameterObject)
+        public IList<T> ExecuteQueryForList<T>(ISqlMapSession session, object parameterObject)
         {
             return this.ExecuteQueryForList<T>(session, parameterObject, MappedStatement.NO_SKIPPED_RESULTS, MappedStatement.NO_MAXIMUM_RESULTS);
         }
@@ -341,7 +339,7 @@
 		/// <param name="session">The session used to execute the statement.</param>
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <returns>The object</returns>
-		public object ExecuteQueryForObject(IDalSession session, object parameterObject)
+		public object ExecuteQueryForObject(ISqlMapSession session, object parameterObject)
 		{
 			return this.ExecuteQueryForObject(session, parameterObject, null);
 		}
@@ -354,7 +352,7 @@
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <param name="resultObject">The result object.</param>
 		/// <returns>The object</returns>
-		public object ExecuteQueryForObject(IDalSession session, object parameterObject, object resultObject)
+		public object ExecuteQueryForObject(ISqlMapSession session, object parameterObject, object resultObject)
 		{
 			object obj = null;
 			RequestScope request = this.Statement.Sql.GetRequestScope(this, parameterObject, session);
@@ -389,7 +387,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>The object</returns>
-        public T ExecuteQueryForObject<T>(IDalSession session, object parameterObject)
+        public T ExecuteQueryForObject<T>(ISqlMapSession session, object parameterObject)
         {
             return this.ExecuteQueryForObject<T>(session, parameterObject, default(T));
         }
@@ -402,7 +400,7 @@
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">The result object.</param>
         /// <returns>The object</returns>
-        public T ExecuteQueryForObject<T>(IDalSession session, object parameterObject, T resultObject)
+        public T ExecuteQueryForObject<T>(ISqlMapSession session, object parameterObject, T resultObject)
         {
             T obj = default(T);
             RequestScope request = this.Statement.Sql.GetRequestScope(this, parameterObject, session);
@@ -437,7 +435,7 @@
 		/// <param name="session">The session used to execute the statement.</param>
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <param name="rowDelegate"></param>
-		public IList ExecuteQueryForRowDelegate(IDalSession session, object parameterObject, RowDelegate rowDelegate)
+		public IList ExecuteQueryForRowDelegate(ISqlMapSession session, object parameterObject, RowDelegate rowDelegate)
 		{
 			return _mappedStatement.ExecuteQueryForRowDelegate(session, parameterObject, rowDelegate);
 		}
@@ -450,7 +448,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="rowDelegate"></param>
-        public IList<T> ExecuteQueryForRowDelegate<T>(IDalSession session, object parameterObject, RowDelegate<T> rowDelegate)
+        public IList<T> ExecuteQueryForRowDelegate<T>(ISqlMapSession session, object parameterObject, RowDelegate<T> rowDelegate)
         {
             return _mappedStatement.ExecuteQueryForRowDelegate<T>(session, parameterObject, rowDelegate);
         }
@@ -467,7 +465,7 @@
 		/// <param name="rowDelegate"></param>
 		/// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
 		/// <exception cref="IBatisNet.DataMapper.Exceptions.DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-		public IDictionary ExecuteQueryForMapWithRowDelegate(IDalSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate rowDelegate)
+		public IDictionary ExecuteQueryForMapWithRowDelegate(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate rowDelegate)
 		{
 			return _mappedStatement.ExecuteQueryForMapWithRowDelegate(session, parameterObject, keyProperty, valueProperty, rowDelegate);
 		}

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/DeleteMappedStatement.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/DeleteMappedStatement.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/DeleteMappedStatement.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/DeleteMappedStatement.cs Sun Nov 19 08:07:45 2006
@@ -1,4 +1,3 @@
-
 #region Apache Notice
 /*****************************************************************************
  * $Header: $
@@ -24,11 +23,10 @@
  ********************************************************************************/
 #endregion
 
-using System;
+
 using System.Collections;
 
 using IBatisNet.DataMapper.Exceptions;
-using IBatisNet.Common;
 using IBatisNet.DataMapper.Configuration.Statements;
 
 namespace IBatisNet.DataMapper.MappedStatements
@@ -57,7 +55,7 @@
 		/// <param name="keyProperty"></param>
 		/// <param name="valueProperty"></param>
 		/// <returns></returns>
-		public override IDictionary ExecuteQueryForMap( IDalSession session, object parameterObject, string keyProperty, string valueProperty )
+		public override IDictionary ExecuteQueryForMap(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty )
 		{
 			throw new DataMapperException("Delete statements cannot be executed as a query for map.");
 		}
@@ -72,7 +70,7 @@
 		/// <param name="session"></param>
 		/// <param name="parameterObject"></param>
 		/// <returns></returns>
-		public override object ExecuteInsert(IDalSession session, object parameterObject )
+        public override object ExecuteInsert(ISqlMapSession session, object parameterObject)
 		{
 			throw new DataMapperException("Delete statements cannot be executed as a query insert.");
 		}
@@ -87,7 +85,7 @@
 		/// <param name="session"></param>
 		/// <param name="parameterObject"></param>
 		/// <param name="resultObject"></param>
-		public override void ExecuteQueryForList(IDalSession session, object parameterObject, IList resultObject )
+        public override void ExecuteQueryForList(ISqlMapSession session, object parameterObject, IList resultObject)
 		{
 			throw new DataMapperException("Delete statements cannot be executed as a query for list.");
 		}
@@ -100,7 +98,7 @@
 		/// <param name="skipResults"></param>
 		/// <param name="maxResults"></param>
 		/// <returns></returns>
-		public override IList ExecuteQueryForList( IDalSession session, object parameterObject, int skipResults, int maxResults )
+        public override IList ExecuteQueryForList(ISqlMapSession session, object parameterObject, int skipResults, int maxResults)
 		{
 			throw new DataMapperException("Delete statements cannot be executed as a query for list.");
 		}
@@ -111,7 +109,7 @@
 		/// <param name="session"></param>
 		/// <param name="parameterObject"></param>
 		/// <returns></returns>
-		public override IList ExecuteQueryForList( IDalSession session, object parameterObject )
+        public override IList ExecuteQueryForList(ISqlMapSession session, object parameterObject)
 		{
 			throw new DataMapperException("Delete statements cannot be executed as a query for list.");
 		}
@@ -125,7 +123,7 @@
 		/// <param name="parameterObject"></param>
 		/// <param name="rowDelegate"></param>
 		/// <returns></returns>
-		public override IList ExecuteQueryForRowDelegate( IDalSession session, object parameterObject, RowDelegate rowDelegate )
+        public override IList ExecuteQueryForRowDelegate(ISqlMapSession session, object parameterObject, RowDelegate rowDelegate)
 		{
 			throw new DataMapperException("Delete statements cannot be executed as a query for row delegate.");
 		}
@@ -139,7 +137,7 @@
 		/// <param name="session"></param>
 		/// <param name="parameterObject"></param>
 		/// <returns></returns>
-		public override object ExecuteQueryForObject( IDalSession session, object parameterObject )
+        public override object ExecuteQueryForObject(ISqlMapSession session, object parameterObject)
 		{
 			throw new DataMapperException("Delete statements cannot be executed as a query for object.");
 		}
@@ -151,7 +149,7 @@
 		/// <param name="parameterObject"></param>
 		/// <param name="resultObject"></param>
 		/// <returns></returns>
-		public override object ExecuteQueryForObject( IDalSession session, object parameterObject, object resultObject )
+        public override object ExecuteQueryForObject(ISqlMapSession session, object parameterObject, object resultObject)
 		{
 			throw new DataMapperException("Delete statements cannot be executed as a query for object.");
 		}

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/IMappedStatement.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/IMappedStatement.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/IMappedStatement.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/IMappedStatement.cs Sun Nov 19 08:07:45 2006
@@ -25,14 +25,11 @@
 #endregion
 
 #region Imports
-using System;
 using System.Collections;
 #if dotnet2
 using System.Collections.Generic;
 #endif
-using IBatisNet.Common;
 using IBatisNet.DataMapper.Commands;
-using IBatisNet.DataMapper.Configuration.ResultMapping;
 using IBatisNet.DataMapper.Configuration.Statements;
 #endregion
 
@@ -109,7 +106,7 @@
 		/// <param name="valueProperty">The property of the result object to be used as the value (or null)</param>
 		/// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
 		///<exception cref="IBatisNet.DataMapper.Exceptions.DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-		IDictionary ExecuteQueryForMap( IDalSession session, object parameterObject, string keyProperty, string valueProperty );
+		IDictionary ExecuteQueryForMap( ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty );
 
 		#endregion
 
@@ -126,7 +123,7 @@
         /// <param name="valueProperty">The property of the result object to be used as the value (or null)</param>
         /// <returns>A IDictionary of object containing the rows keyed by keyProperty.</returns>
         ///<exception cref="IBatisNet.DataMapper.Exceptions.DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-        IDictionary<K, V> ExecuteQueryForDictionary<K, V>(IDalSession session, object parameterObject, string keyProperty, string valueProperty);
+        IDictionary<K, V> ExecuteQueryForDictionary<K, V>(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty);
 
         /// <summary>
         /// Runs a query with a custom object that gets a chance 
@@ -139,7 +136,7 @@
         /// <param name="rowDelegate">A delegate called once per row in the QueryForDictionary method</param>
         /// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
         /// <exception cref="IBatisNet.DataMapper.Exceptions.DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-        IDictionary<K, V> ExecuteQueryForDictionary<K, V>(IDalSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate<K, V> rowDelegate);
+        IDictionary<K, V> ExecuteQueryForDictionary<K, V>(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate<K, V> rowDelegate);
 
 
 #endif
@@ -154,7 +151,7 @@
 		/// <param name="session">The session used to execute the statement.</param>
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <returns>The number of row effected.</returns>
-		int ExecuteUpdate(IDalSession session, object parameterObject );
+		int ExecuteUpdate(ISqlMapSession session, object parameterObject );
 
 		#endregion
 
@@ -167,7 +164,7 @@
 		/// <param name="session">The session</param>
 		/// <param name="parameterObject">The parameter object used to fill the statement.</param>
 		/// <returns>Can return the insert generated key.</returns>
-		object ExecuteInsert(IDalSession session, object parameterObject );
+		object ExecuteInsert(ISqlMapSession session, object parameterObject );
 
 		#endregion
 
@@ -179,7 +176,7 @@
 		/// <param name="session">The session used to execute the statement.</param>
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <param name="resultObject">A strongly typed collection of result objects.</param>
-		void ExecuteQueryForList(IDalSession session, object parameterObject, IList resultObject );
+		void ExecuteQueryForList(ISqlMapSession session, object parameterObject, IList resultObject );
 
 		/// <summary>
 		/// Executes the SQL and retuns a subset of the rows selected.
@@ -189,7 +186,7 @@
 		/// <param name="skipResults">The number of rows to skip over.</param>
 		/// <param name="maxResults">The maximum number of rows to return.</param>
 		/// <returns>A List of result objects.</returns>
-		IList ExecuteQueryForList( IDalSession session, object parameterObject, int skipResults, int maxResults );
+		IList ExecuteQueryForList( ISqlMapSession session, object parameterObject, int skipResults, int maxResults );
 
 		/// <summary>
 		/// Executes the SQL and retuns all rows selected. This is exactly the same as
@@ -198,7 +195,7 @@
 		/// <param name="session">The session used to execute the statement.</param>
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <returns>A List of result objects.</returns>
-		IList ExecuteQueryForList( IDalSession session, object parameterObject );
+		IList ExecuteQueryForList( ISqlMapSession session, object parameterObject );
 
 		#endregion
 
@@ -210,7 +207,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">A strongly typed collection of result objects.</param>
-        void ExecuteQueryForList<T>(IDalSession session, object parameterObject, IList<T> resultObject);
+        void ExecuteQueryForList<T>(ISqlMapSession session, object parameterObject, IList<T> resultObject);
 
         /// <summary>
         /// Executes the SQL and retuns a subset of the rows selected.
@@ -220,7 +217,7 @@
         /// <param name="skipResults">The number of rows to skip over.</param>
         /// <param name="maxResults">The maximum number of rows to return.</param>
         /// <returns>A List of result objects.</returns>
-        IList<T> ExecuteQueryForList<T>(IDalSession session, object parameterObject, int skipResults, int maxResults);
+        IList<T> ExecuteQueryForList<T>(ISqlMapSession session, object parameterObject, int skipResults, int maxResults);
 
         /// <summary>
         /// Executes the SQL and retuns all rows selected. This is exactly the same as
@@ -229,7 +226,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>A List of result objects.</returns>
-        IList<T> ExecuteQueryForList<T>(IDalSession session, object parameterObject);
+        IList<T> ExecuteQueryForList<T>(ISqlMapSession session, object parameterObject);
 #endif
         #endregion
 
@@ -241,7 +238,7 @@
 		/// <param name="session">The session used to execute the statement.</param>
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <returns>The object</returns>
-		object ExecuteQueryForObject( IDalSession session, object parameterObject );
+		object ExecuteQueryForObject( ISqlMapSession session, object parameterObject );
 
 		/// <summary>
 		/// Executes an SQL statement that returns a single row as an Object of the type of
@@ -251,7 +248,7 @@
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <param name="resultObject">The result object.</param>
 		/// <returns>The object</returns>
-		object ExecuteQueryForObject( IDalSession session, object parameterObject, object resultObject );
+		object ExecuteQueryForObject( ISqlMapSession session, object parameterObject, object resultObject );
 
 		#endregion
 
@@ -264,7 +261,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>The object</returns>
-        T ExecuteQueryForObject<T>(IDalSession session, object parameterObject);
+        T ExecuteQueryForObject<T>(ISqlMapSession session, object parameterObject);
 
         /// <summary>
         /// Executes an SQL statement that returns a single row as an Object of the type of
@@ -274,7 +271,7 @@
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">The result object.</param>
         /// <returns>The object</returns>
-        T ExecuteQueryForObject<T>(IDalSession session, object parameterObject, T resultObject);
+        T ExecuteQueryForObject<T>(ISqlMapSession session, object parameterObject, T resultObject);
 #endif
         #endregion
 
@@ -288,7 +285,7 @@
 		/// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
 		/// <param name="rowDelegate"></param>param>
 		/// <returns></returns>
-		IList ExecuteQueryForRowDelegate( IDalSession session, object parameterObject, RowDelegate rowDelegate );
+		IList ExecuteQueryForRowDelegate( ISqlMapSession session, object parameterObject, RowDelegate rowDelegate );
 
  
 		/// <summary>
@@ -302,7 +299,7 @@
 		/// <param name="rowDelegate"></param>
 		/// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
 		/// <exception cref="IBatisNet.DataMapper.Exceptions.DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-		IDictionary ExecuteQueryForMapWithRowDelegate( IDalSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate rowDelegate );
+		IDictionary ExecuteQueryForMapWithRowDelegate( ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate rowDelegate );
 
 		#endregion 
 		
@@ -316,7 +313,7 @@
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="rowDelegate"></param>param>
         /// <returns></returns>
-        IList<T> ExecuteQueryForRowDelegate<T>(IDalSession session, object parameterObject, RowDelegate<T> rowDelegate);
+        IList<T> ExecuteQueryForRowDelegate<T>(ISqlMapSession session, object parameterObject, RowDelegate<T> rowDelegate);
 #endif
         #endregion
 	    

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/InsertMappedStatement.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/InsertMappedStatement.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/InsertMappedStatement.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/InsertMappedStatement.cs Sun Nov 19 08:07:45 2006
@@ -1,4 +1,3 @@
-
 #region Apache Notice
 /*****************************************************************************
  * $Header: $
@@ -24,11 +23,9 @@
  ********************************************************************************/
 #endregion
 
-using System;
-using System.Collections;
 
+using System.Collections;
 using IBatisNet.DataMapper.Exceptions;
-using IBatisNet.Common;
 using IBatisNet.DataMapper.Configuration.Statements;
 
 namespace IBatisNet.DataMapper.MappedStatements
@@ -57,7 +54,7 @@
 		/// <param name="keyProperty"></param>
 		/// <param name="valueProperty"></param>
 		/// <returns></returns>
-		public override IDictionary ExecuteQueryForMap( IDalSession session, object parameterObject, string keyProperty, string valueProperty )
+		public override IDictionary ExecuteQueryForMap(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty )
 		{
 			throw new DataMapperException("Insert statements cannot be executed as a query for map.");
 		}
@@ -72,7 +69,7 @@
 		/// <param name="session"></param>
 		/// <param name="parameterObject"></param>
 		/// <returns></returns>
-		public override int ExecuteUpdate(IDalSession session, object parameterObject )
+		public override int ExecuteUpdate(ISqlMapSession session, object parameterObject )
 		{
 			throw new DataMapperException("Insert statements cannot be executed as a update query.");
 		}
@@ -87,7 +84,7 @@
 		/// <param name="session"></param>
 		/// <param name="parameterObject"></param>
 		/// <param name="resultObject"></param>
-		public override void ExecuteQueryForList(IDalSession session, object parameterObject, IList resultObject )
+		public override void ExecuteQueryForList(ISqlMapSession session, object parameterObject, IList resultObject )
 		{
 			throw new DataMapperException("Insert statements cannot be executed as a query for list.");
 		}
@@ -100,7 +97,7 @@
 		/// <param name="skipResults"></param>
 		/// <param name="maxResults"></param>
 		/// <returns></returns>
-		public override IList ExecuteQueryForList( IDalSession session, object parameterObject, int skipResults, int maxResults )
+		public override IList ExecuteQueryForList(ISqlMapSession session, object parameterObject, int skipResults, int maxResults )
 		{
 			throw new DataMapperException("Insert statements cannot be executed as a query for list.");
 		}
@@ -111,7 +108,7 @@
 		/// <param name="session"></param>
 		/// <param name="parameterObject"></param>
 		/// <returns></returns>
-		public override IList ExecuteQueryForList( IDalSession session, object parameterObject )
+		public override IList ExecuteQueryForList(ISqlMapSession session, object parameterObject )
 		{
 			throw new DataMapperException("Insert statements cannot be executed as a query for list.");
 		}
@@ -127,7 +124,7 @@
 		/// <param name="parameterObject"></param>
 		/// <param name="rowDelegate"></param>
 		/// <returns></returns>
-		public override IList ExecuteQueryForRowDelegate( IDalSession session, object parameterObject, RowDelegate rowDelegate )
+		public override IList ExecuteQueryForRowDelegate(ISqlMapSession session, object parameterObject, RowDelegate rowDelegate )
 		{
 			throw new DataMapperException("Insert statements cannot be executed as a query for row delegate.");
 		}
@@ -143,7 +140,7 @@
 		/// <param name="rowDelegate"></param>
 		/// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
 		///<exception cref="DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-		public override IDictionary ExecuteQueryForMapWithRowDelegate( IDalSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate rowDelegate )
+		public override IDictionary ExecuteQueryForMapWithRowDelegate(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate rowDelegate )
 		{
 			throw new DataMapperException("Insert statements cannot be executed as a query for row delegate.");
 		}
@@ -157,7 +154,7 @@
 		/// <param name="session"></param>
 		/// <param name="parameterObject"></param>
 		/// <returns></returns>
-		public override object ExecuteQueryForObject( IDalSession session, object parameterObject )
+		public override object ExecuteQueryForObject(ISqlMapSession session, object parameterObject )
 		{
 			throw new DataMapperException("Insert statements cannot be executed as a query for object.");
 		}
@@ -169,7 +166,7 @@
 		/// <param name="parameterObject"></param>
 		/// <param name="resultObject"></param>
 		/// <returns></returns>
-		public override object ExecuteQueryForObject( IDalSession session, object parameterObject, object resultObject )
+        public override object ExecuteQueryForObject(ISqlMapSession session, object parameterObject, object resultObject)
 		{
 			throw new DataMapperException("Insert statements cannot be executed as a query for object.");
 		}

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs Sun Nov 19 08:07:45 2006
@@ -34,7 +34,6 @@
 using System.Data;
 using System.Text;
 
-using IBatisNet.Common;
 using IBatisNet.Common.Utilities.Objects;
 
 
@@ -138,7 +137,7 @@
         /// <param name="session">The current session.</param>
         /// <param name="result">The result object.</param>
         /// <param name="command">The command sql.</param>
-        private void RetrieveOutputParameters(RequestScope request, IDalSession session, IDbCommand command, object result)
+        private void RetrieveOutputParameters(RequestScope request, ISqlMapSession session, IDbCommand command, object result)
         {
             if (request.ParameterMap != null)
             {
@@ -191,7 +190,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>The object</returns>
-        public virtual object ExecuteQueryForObject(IDalSession session, object parameterObject)
+        public virtual object ExecuteQueryForObject(ISqlMapSession session, object parameterObject)
         {
             return ExecuteQueryForObject(session, parameterObject, null);
         }
@@ -205,7 +204,7 @@
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">The result object.</param>
         /// <returns>The object</returns>
-        public virtual object ExecuteQueryForObject(IDalSession session, object parameterObject, object resultObject)
+        public virtual object ExecuteQueryForObject(ISqlMapSession session, object parameterObject, object resultObject)
         {
             object obj = null;
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
@@ -227,7 +226,7 @@
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">The result object.</param>
         /// <returns>The object</returns>
-        internal object RunQueryForObject(RequestScope request, IDalSession session, object parameterObject, object resultObject)
+        internal object RunQueryForObject(RequestScope request, ISqlMapSession session, object parameterObject, object resultObject)
         {
             object result = resultObject;
 
@@ -277,7 +276,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>The object</returns>
-        public virtual T ExecuteQueryForObject<T>(IDalSession session, object parameterObject)
+        public virtual T ExecuteQueryForObject<T>(ISqlMapSession session, object parameterObject)
         {
             return ExecuteQueryForObject<T>(session, parameterObject, default(T));
         }
@@ -291,7 +290,7 @@
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">The result object.</param>
         /// <returns>The object</returns>
-        public virtual T ExecuteQueryForObject<T>(IDalSession session, object parameterObject, T resultObject)
+        public virtual T ExecuteQueryForObject<T>(ISqlMapSession session, object parameterObject, T resultObject)
         {
             T obj = default(T);
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
@@ -313,7 +312,7 @@
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">The result object.</param>
         /// <returns>The object</returns>
-        internal T RunQueryForObject<T>(RequestScope request, IDalSession session, object parameterObject, T resultObject)
+        internal T RunQueryForObject<T>(RequestScope request, ISqlMapSession session, object parameterObject, T resultObject)
         {
             T result = resultObject;
 
@@ -363,7 +362,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="rowDelegate"></param>
-        public virtual IList ExecuteQueryForRowDelegate(IDalSession session, object parameterObject, RowDelegate rowDelegate)
+        public virtual IList ExecuteQueryForRowDelegate(ISqlMapSession session, object parameterObject, RowDelegate rowDelegate)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -388,7 +387,7 @@
         /// <param name="rowDelegate"></param>
         /// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
         ///<exception cref="DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-        public virtual IDictionary ExecuteQueryForMapWithRowDelegate(IDalSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate rowDelegate)
+        public virtual IDictionary ExecuteQueryForMapWithRowDelegate(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate rowDelegate)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -410,7 +409,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>A List of result objects.</returns>
-        public virtual IList ExecuteQueryForList(IDalSession session, object parameterObject)
+        public virtual IList ExecuteQueryForList(ISqlMapSession session, object parameterObject)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -428,7 +427,7 @@
         /// <param name="skipResults">The number of rows to skip over.</param>
         /// <param name="maxResults">The maximum number of rows to return.</param>
         /// <returns>A List of result objects.</returns>
-        public virtual IList ExecuteQueryForList(IDalSession session, object parameterObject, int skipResults, int maxResults)
+        public virtual IList ExecuteQueryForList(ISqlMapSession session, object parameterObject, int skipResults, int maxResults)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -446,7 +445,7 @@
         /// <param name="skipResults">The number of rows to skip over.</param>
         /// <param name="maxResults">The maximum number of rows to return.</param>
         /// <returns>A List of result objects.</returns>
-        internal IList RunQueryForList(RequestScope request, IDalSession session, object parameterObject, int skipResults, int maxResults)
+        internal IList RunQueryForList(RequestScope request, ISqlMapSession session, object parameterObject, int skipResults, int maxResults)
         {
             IList list = null;
             
@@ -514,7 +513,7 @@
         /// <param name="resultObject">A strongly typed collection of result objects.</param>
         /// <param name="rowDelegate"></param>
         /// <returns>A List of result objects.</returns>
-        internal IList RunQueryForList(RequestScope request, IDalSession session, object parameterObject, IList resultObject, RowDelegate rowDelegate)
+        internal IList RunQueryForList(RequestScope request, ISqlMapSession session, object parameterObject, IList resultObject, RowDelegate rowDelegate)
         {
             IList list = resultObject;
 
@@ -584,7 +583,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">A strongly typed collection of result objects.</param>
-        public virtual void ExecuteQueryForList(IDalSession session, object parameterObject, IList resultObject)
+        public virtual void ExecuteQueryForList(ISqlMapSession session, object parameterObject, IList resultObject)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -606,7 +605,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="rowDelegate"></param>
-        public virtual IList<T> ExecuteQueryForRowDelegate<T>(IDalSession session, object parameterObject, RowDelegate<T> rowDelegate)
+        public virtual IList<T> ExecuteQueryForRowDelegate<T>(ISqlMapSession session, object parameterObject, RowDelegate<T> rowDelegate)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -627,7 +626,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>A List of result objects.</returns>
-        public virtual IList<T> ExecuteQueryForList<T>(IDalSession session, object parameterObject)
+        public virtual IList<T> ExecuteQueryForList<T>(ISqlMapSession session, object parameterObject)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -645,7 +644,7 @@
         /// <param name="skipResults">The number of rows to skip over.</param>
         /// <param name="maxResults">The maximum number of rows to return.</param>
         /// <returns>A List of result objects.</returns>
-        public virtual IList<T> ExecuteQueryForList<T>(IDalSession session, object parameterObject, int skipResults, int maxResults)
+        public virtual IList<T> ExecuteQueryForList<T>(ISqlMapSession session, object parameterObject, int skipResults, int maxResults)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -664,7 +663,7 @@
         /// <param name="skipResults">The number of rows to skip over.</param>
         /// <param name="maxResults">The maximum number of rows to return.</param>
         /// <returns>A List of result objects.</returns>
-        internal IList<T> RunQueryForList<T>(RequestScope request, IDalSession session, object parameterObject, int skipResults, int maxResults)
+        internal IList<T> RunQueryForList<T>(RequestScope request, ISqlMapSession session, object parameterObject, int skipResults, int maxResults)
         {
             IList<T> list = null;
 
@@ -730,7 +729,7 @@
         /// <param name="resultObject">The result object</param>
         /// <param name="rowDelegate"></param>
         /// <returns>A List of result objects.</returns>
-        internal IList<T> RunQueryForList<T>(RequestScope request, IDalSession session, 
+        internal IList<T> RunQueryForList<T>(RequestScope request, ISqlMapSession session, 
                                              object parameterObject, IList<T> resultObject, RowDelegate<T> rowDelegate)
         {
             IList<T> list = resultObject;
@@ -799,7 +798,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <param name="resultObject">A strongly typed collection of result objects.</param>
-        public virtual void ExecuteQueryForList<T>(IDalSession session, object parameterObject, IList<T> resultObject)
+        public virtual void ExecuteQueryForList<T>(ISqlMapSession session, object parameterObject, IList<T> resultObject)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -820,7 +819,7 @@
         /// <param name="session">The session used to execute the statement.</param>
         /// <param name="parameterObject">The object used to set the parameters in the SQL.</param>
         /// <returns>The number of row effected.</returns>
-        public virtual int ExecuteUpdate(IDalSession session, object parameterObject)
+        public virtual int ExecuteUpdate(ISqlMapSession session, object parameterObject)
         {
             int rows = 0; // the number of rows affected
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
@@ -849,7 +848,7 @@
         /// <param name="session">The session</param>
         /// <param name="parameterObject">The parameter object used to fill the statement.</param>
         /// <returns>Can return the insert generated key.</returns>
-        public virtual object ExecuteInsert(IDalSession session, object parameterObject)
+        public virtual object ExecuteInsert(ISqlMapSession session, object parameterObject)
         {
             object generatedKey = null;
             SelectKey selectKeyStatement = null;
@@ -937,7 +936,7 @@
         /// <param name="valueProperty">The property of the result object to be used as the value (or null)</param>
         /// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
         ///<exception cref="DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-        public virtual IDictionary ExecuteQueryForMap(IDalSession session, object parameterObject, string keyProperty, string valueProperty)
+        public virtual IDictionary ExecuteQueryForMap(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -961,7 +960,7 @@
         /// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
         ///<exception cref="DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
         internal IDictionary RunQueryForMap(RequestScope request,
-            IDalSession session,
+            ISqlMapSession session,
             object parameterObject,
             string keyProperty,
             string valueProperty,
@@ -1031,7 +1030,7 @@
         /// <param name="valueProperty">The property of the result object to be used as the value (or null)</param>
         /// <returns>A IDictionary of object containing the rows keyed by keyProperty.</returns>
         ///<exception cref="IBatisNet.DataMapper.Exceptions.DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-        public virtual IDictionary<K, V> ExecuteQueryForDictionary<K, V>(IDalSession session, object parameterObject, string keyProperty, string valueProperty)
+        public virtual IDictionary<K, V> ExecuteQueryForDictionary<K, V>(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -1052,7 +1051,7 @@
         /// <param name="rowDelegate">A delegate called once per row in the QueryForDictionary method</param>
         /// <returns>A hashtable of object containing the rows keyed by keyProperty.</returns>
         ///<exception cref="DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
-        public virtual IDictionary<K, V> ExecuteQueryForDictionary<K, V>(IDalSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate<K, V> rowDelegate)
+        public virtual IDictionary<K, V> ExecuteQueryForDictionary<K, V>(ISqlMapSession session, object parameterObject, string keyProperty, string valueProperty, DictionaryRowDelegate<K, V> rowDelegate)
         {
             RequestScope request = _statement.Sql.GetRequestScope(this, parameterObject, session);
 
@@ -1080,7 +1079,7 @@
         /// <returns>A IDictionary of object containing the rows keyed by keyProperty.</returns>
         ///<exception cref="DataMapperException">If a transaction is not in progress, or the database throws an exception.</exception>
         internal IDictionary<K, V> RunQueryForDictionary<K, V>(RequestScope request,
-            IDalSession session,
+            ISqlMapSession session,
             object parameterObject,
             string keyProperty,
             string valueProperty,

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PaginatedList.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PaginatedList.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PaginatedList.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PaginatedList.cs Sun Nov 19 08:07:45 2006
@@ -27,7 +27,6 @@
 using System;
 using System.Collections;
 
-using IBatisNet.Common;
 using IBatisNet.Common.Pagination;
 using IBatisNet.DataMapper.Exceptions;
 
@@ -202,7 +201,7 @@
 		{
 			bool isSessionLocal = false;
 
-			IDalSession session = _mappedStatement.SqlMap.LocalSession;
+			ISqlMapSession session = _mappedStatement.SqlMap.LocalSession;
 
 			if (session == null) 
 			{

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PostSelectStrategy/GenericListStrategy.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PostSelectStrategy/GenericListStrategy.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PostSelectStrategy/GenericListStrategy.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PostSelectStrategy/GenericListStrategy.cs Sun Nov 19 08:07:45 2006
@@ -56,7 +56,7 @@
 
             Type mappedStatementType = postSelect.Statement.GetType();
 
-            Type[] typeArguments = { typeof(IDalSession), typeof(object) };
+            Type[] typeArguments = { typeof(SqlMapSession), typeof(object) };
 
             MethodInfo[] mis = mappedStatementType.GetMethods(BindingFlags.InvokeMethod | BindingFlags.Public | BindingFlags.Instance);
             MethodInfo mi = null;

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PropertStrategy/SelectGenericListStrategy.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PropertStrategy/SelectGenericListStrategy.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PropertStrategy/SelectGenericListStrategy.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/PropertStrategy/SelectGenericListStrategy.cs Sun Nov 19 08:07:45 2006
@@ -88,6 +88,7 @@
         /// <param name="resultMap">The result map.</param>
         /// <param name="mapping">The mapping.</param>
         /// <param name="reader">The reader.</param>
+        /// <param name="target">The target object</param>
         public object Get(RequestScope request, IResultMap resultMap, ResultProperty mapping, ref object target, IDataReader reader)
         {
             throw new NotSupportedException("Get method on ResultMapStrategy is not supported");
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs Sun Nov 19 08:07:45 2006
@@ -59,17 +59,17 @@
 		#region IPreparedCommand Members
 
 		/// <summary>
 		/// Create an IDbCommand for the IDalSession and the current SQL Statement
 		/// and fill IDbCommand IDataParameter's with the parameterObject.
 		/// </summary>
 		/// <param name="request"></param>
-		/// <param name="session">The IDalSession</param>
+		/// <param name="session">The SqlMapSession</param>
 		/// <param name="statement">The IStatement</param>
 		/// <param name="parameterObject">
 		/// The parameter object that will fill the sql parameter
 		/// </param>
 		/// <returns>An IDbCommand with all the IDataParameter filled.</returns>
-		public void Create(RequestScope request, IDalSession session, IStatement statement, object parameterObject )
+		public void Create(RequestScope request, ISqlMapSession session, IStatement statement, object parameterObject )
 		{
 			// the IDbConnection & the IDbTransaction are assign in the CreateCommand 
             request.IDbCommand = new DbCommandDecorator(session.CreateCommand(statement.CommandType), request);
@@ -94,7 +94,7 @@
         /// <param name="statement">The statement.</param>
         /// <param name="parameterObject">The parameter object.</param>
 		protected virtual void ApplyParameterMap
-			( IDalSession session, IDbCommand command,
+			( ISqlMapSession session, IDbCommand command,
 			RequestScope request, IStatement statement, object parameterObject )
 		{
 			StringCollection properties = request.PreparedStatement.DbParametersName;
@@ -59,17 +59,17 @@
 
 		/// <summary>
-		/// Create an IDbCommand for the IDalSession and the current SQL Statement
+		/// Create an IDbCommand for the SqlMapSession and the current SQL Statement
 		/// and fill IDbCommand IDataParameter's with the parameterObject.
 		/// </summary>

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/IPreparedCommand.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/IPreparedCommand.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================
--- ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/IPreparedCommand.cs (original)
+++ ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/IPreparedCommand.cs Sun Nov 19 08:07:45 2006
@@ -2,7 +2,7 @@
 #region Apache Notice
 /*****************************************************************************
  * $Header: $
- * $Revision: $
+ * $Revision$
  * $Date$
  * 
  * iBATIS.NET Data Mapper
@@ -25,9 +25,7 @@
 #endregion
 
 #region Imports
-using System.Data;
 
-using IBatisNet.Common;
 using IBatisNet.DataMapper.Configuration.Statements;
 using IBatisNet.DataMapper.Scope;
 
@@ -41,16 +39,16 @@
 	public interface IPreparedCommand
 	{
 		/// <summary>
 		/// Create an IDbCommand for the IDalSession and the current SQL Statement
 		/// and fill IDbCommand IDataParameter's with the parameterObject.
 		/// </summary>
 		/// <param name="request"></param>
-		/// <param name="session">The IDalSession</param>
+		/// <param name="session">The SqlMapSession</param>
 		/// <param name="statement">The IStatement</param>
 		/// <param name="parameterObject">
 		/// The parameter object that will fill the sql parameter
 		/// </param>
 		/// <returns>An IDbCommand with all the IDataParameter filled.</returns>
-		void Create (RequestScope request, IDalSession session, IStatement statement, object parameterObject );
+		void Create (RequestScope request, ISqlMapSession session, IStatement statement, object parameterObject );
 	}
 }
@@ -41,16 +39,16 @@
 	{
 		/// <summary>
-		/// Create an IDbCommand for the IDalSession and the current SQL Statement
+		/// Create an IDbCommand for the SqlMapSession and the current SQL Statement
 		/// and fill IDbCommand IDataParameter's with the parameterObject.
 		/// </summary>

Modified: ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs
URL: http://svn.apache.org/viewvc/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs?view=diff&rev=476843&r1=476842&r2=476843
==============================================================================